==> haskell-swagger2-2.3.1.1-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.3.1.1
id: swagger2-2.3.1.1-4FRzXx2gE2z4BmHOS0qLhU
key: swagger2-2.3.1.1-4FRzXx2gE2z4BmHOS0qLhU
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 409c2380e7dd778c7cad6a84c4a51954
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Generator
    Data.Swagger.Schema.Validation Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.5/site-local/swagger2-2.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/swagger2-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/swagger2-2.3.1.1
hs-libraries: HSswagger2-2.3.1.1-4FRzXx2gE2z4BmHOS0qLhU
depends:
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s base-4.12.0.0
    base-compat-batteries-0.11.0-rcvb9Df6llIePiFdWxTK3
    bytestring-0.10.8.2 containers-0.6.0.1
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC
    generics-sop-0.5.0.0-KcRCSh2JEyL6JzNJdcWr49
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    insert-ordered-containers-0.2.2-2GOc27HU9TiBeKdnl40qTD
    lens-4.17.1-7S5lGb7ZxVusQDqQpE4dD mtl-2.2.2
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.3.1.1-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.3.1.1
id: swagger2-2.3.1.1-zfpO8iY9Hz6oliKEX77HC
key: swagger2-2.3.1.1-zfpO8iY9Hz6oliKEX77HC
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 5bb2d41b74e779195722c31d44b7529a
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Generator
    Data.Swagger.Schema.Validation Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.5/site-local/swagger2-2.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/swagger2-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/swagger2-2.3.1.1
hs-libraries: HSswagger2-2.3.1.1-zfpO8iY9Hz6oliKEX77HC
depends:
    QuickCheck-2.13.2-8Fp36mG21e67uRy7VcQZNU
    aeson-1.4.6.0-ByJnT4jukmB1Ih4DIu8bQB base-4.12.0.0
    base-compat-batteries-0.11.0-BlEB46ybD1O5p7XX5pW4ka
    bytestring-0.10.8.2 containers-0.6.0.1
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC
    generics-sop-0.5.0.0-KcRCSh2JEyL6JzNJdcWr49
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    insert-ordered-containers-0.2.2-E8xb3LNXUzE5DERuHGKcRh
    lens-4.17.1-FKLB3klUZnP1VUCoa2NPRL mtl-2.2.2
    network-2.8.0.1-L17Rv8Nouqq1qZnRto8DBo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-EKmGslSZSRGGEQm9fn2qPS
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
